| Title: | Matrix-Variate Variance-Gamma Distribution |
|---|---|
| Description: | Rudimentary functions for sampling and calculating density from the matrix-variate variance-gamma distribution. |
| Authors: | Samuel Soon [aut, cre] |
| Maintainer: | Samuel Soon <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-12 07:43:00 UTC |
| Source: | https://github.com/cran/mvvg |
Determines density of observations from a Matrix-variate variance gamma (MVVG) distribution, under the identifiability constraint set by [].
dmvvg(X, M, A, Sigma, Psi, gamma, log = FALSE)dmvvg(X, M, A, Sigma, Psi, gamma, log = FALSE)
X |
|
M |
|
A |
|
Sigma |
|
Psi |
|
gamma |
scalar mixing parameter |
log |
returns log-likelihood if TRUE, default is FALSE. |
MVVG samples are formulated through the normal variance-mean mixture , where .
Gamma must be . Sigma and Psi must be positive definite covariance matrices.
dmvvg returns the probability density corresponding to the inputted values and parameters.
Samuel Soon
M <- cbind(rep(1, 5), c(1, 0, 1, 0, 1)) A <- matrix(c(1,2), 5, 2, byrow = TRUE) Sigma <- diag(5) Psi <- matrix(c(4,2,2,3), 2, 2) gamma <- 3 X <- rmvvg(1, M, A, Sigma, Psi, gamma)[[1]] dmvvg(X, M, A, Sigma, Psi, gamma)M <- cbind(rep(1, 5), c(1, 0, 1, 0, 1)) A <- matrix(c(1,2), 5, 2, byrow = TRUE) Sigma <- diag(5) Psi <- matrix(c(4,2,2,3), 2, 2) gamma <- 3 X <- rmvvg(1, M, A, Sigma, Psi, gamma)[[1]] dmvvg(X, M, A, Sigma, Psi, gamma)
matrix intended for use as an example in dmvvg.
example_matrixexample_matrix
An object of class matrix (inherits from array) with 5 rows and 2 columns.
Samuel Soon
Generates random samples from the matrix-variate variance gamma (MVVG) distribution, under the identifiability constraint set by [].
rmvvg(n, M, A, Sigma, Psi, gamma)rmvvg(n, M, A, Sigma, Psi, gamma)
n |
number of observations |
M |
|
A |
|
Sigma |
|
Psi |
|
gamma |
scalar mixing parameter |
MVVG samples are formulated through the normal variance-mean mixture , where .
Gamma must be . Sigma and Psi must be positive definite covariance matrices.
rmvvg returns a list of random samples.
Samuel Soon
M <- cbind(rep(1, 5), c(1, 0, 1, 0, 1)) A <- matrix(c(1,2), 5, 2, byrow = TRUE) Sigma <- diag(5) Psi <- matrix(c(4,2,2,3), 2, 2) gamma <- 3 rmvvg(2, M, A, Sigma, Psi, gamma)M <- cbind(rep(1, 5), c(1, 0, 1, 0, 1)) A <- matrix(c(1,2), 5, 2, byrow = TRUE) Sigma <- diag(5) Psi <- matrix(c(4,2,2,3), 2, 2) gamma <- 3 rmvvg(2, M, A, Sigma, Psi, gamma)